@@ -1,12 +1,26 @@
 from dataclasses import dataclass, field
+from enum import Enum, auto
 from typing import List, Union
 
 from hpcrocket.core.environmentpreparation import CopyInstruction
 from hpcrocket.ssh.connectiondata import ConnectionData
 
 
-Options = Union['LaunchOptions', 'StatusOptions', 'WatchOptions']
-MonitoringOptions = Union['StatusOptions', 'WatchOptions']
+Options = Union['LaunchOptions', 'SimpleJobOptions', 'WatchOptions']
+JobBasedOptions = Union['SimpleJobOptions', 'WatchOptions']
+
+
+@dataclass
+class SimpleJobOptions:
+
+    class Action(Enum):
+        status = auto()
+        cancel = auto()
+
+    jobid: str
+    action: Action
+    connection: ConnectionData
+    proxyjumps: List[ConnectionData] = field(default_factory=lambda: [])
 
 
 @dataclass
@@ -21,16 +35,9 @@ class LaunchOptions:
     watch: bool = False
 
 
-@dataclass
-class StatusOptions:
-    jobid: str
-    connection: ConnectionData
-    proxyjumps: List[ConnectionData] = field(default_factory=lambda: [])
-
-
 @dataclass
 class WatchOptions:
     jobid: str
     connection: ConnectionData
     proxyjumps: List[ConnectionData] = field(default_factory=lambda: [])
-    poll_interval: int = 5
\ No newline at end of file
+    poll_interval: int = 5
