@@ -1,10 +1,11 @@
 from typing import List, Optional
 
+from hpcrocket.typesafety import get_or_raise
 from hpcrocket.ui import UI
 
 try:
     from typing import Protocol
-except ImportError:
+except ImportError:  # pragma: no cover
     from typing_extensions import Protocol  # type: ignore
 
 
@@ -14,9 +15,24 @@ class Stage(Protocol):
     """
 
     def __call__(self, ui: UI) -> bool:
+        """
+        Starts running the stage. Returns true if the stage completed successfully.
+
+        Args:
+            ui (UI): The ui to send output to.
+
+        Returns:
+            bool
+        """
         pass
 
     def cancel(self, ui: UI) -> None:
+        """
+        Cancels the stage.
+
+        Args:
+            ui (UI): The ui to send output to.
+        """
         pass
 
 
@@ -31,6 +47,15 @@ class Workflow:
         self._canceled = False
 
     def run(self, ui: UI) -> bool:
+        """
+        Runs the workflow. Returns true if all stages completed successfully.
+
+        Args:
+            ui (UI): The ui to send output to.
+
+        Returns:
+            bool
+        """
         for stage in self._stages:
             self._active_stage = stage
 
@@ -44,13 +69,18 @@ class Workflow:
         return True
 
     def cancel(self, ui: UI) -> None:
-        self._raise_if_not_started()
-        self._active_stage.cancel(ui) # type: ignore
-        self._canceled = True
+        """
+        Cancels the workflow.
 
-    def _raise_if_not_started(self) -> None:
-        if not self._active_stage:
-            raise WorkflowNotStartedError()
+        Args:
+            ui (UI): The ui to send output to.
+
+        Raises:
+            WorkflowNotStartedError: If the workflow is canceled before it was started.
+        """
+        active_stage = get_or_raise(self._active_stage, WorkflowNotStartedError)
+        active_stage.cancel(ui)
+        self._canceled = True
 
 
 class WorkflowNotStartedError(Exception):
